==> adfurikun-1.0.1.tar.gz: lib/ad_base.dart <==
import 'dart:io';
import 'package:flutter/widgets.dart';
import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'adfurikun_plugin.dart';
import 'constants.dart';

abstract class AdfurikunAdBase {
  static int _nextNumber = 0;

  final String appId;
  final String adType;
  late final int number;

  AdfurikunAdBase(this.appId, this.adType) {
    number = _nextNumber++;
    AdfurikunPlugin.registerAd(this);
  }

  String method(String method) {
    return method + SEPARATOR_METHOD + adType;
  }

  Map<String, Object> args() {
    return {KEY_NUMBER: number, KEY_APP_ID: appId};
  }

  Map<String, Object> argsWithSize(double width, double height) {
    return {KEY_NUMBER: number, KEY_APP_ID: appId, KEY_WIDTH: width, KEY_HEIGHT: height};
  }

  void destroy() {
    AdfurikunPlugin.removeAd(this);
  }

  void notifyListener(MethodCall call) {
    print('override notifyListener method');
  }
}

class AdfurikunWidget extends StatefulWidget {
  final int number;
  final String appId;
  final String adType;
  final double width;
  final double height;

  AdfurikunWidget(this.number, this.appId, this.adType, this.width, this.height);

  @override
  AdfurikunWidgetState createState() => AdfurikunWidgetState(number, appId, adType, width, height);
}

class AdfurikunWidgetState extends State<AdfurikunWidget> {
  final int number;
  final String appId;
  final String adType;
  final double width;
  final double height;

  AdfurikunWidgetState(this.number, this.appId, this.adType, this.width, this.height);

  @override
  Widget build(BuildContext context) {
    Map<String, Object> params = {KEY_NUMBER: number, KEY_APP_ID: appId, KEY_WIDTH: width, KEY_HEIGHT: height};
    if (Platform.isAndroid) {
      return AndroidView(
          viewType: ADFURIKUN_VIEW_TYPE_BASE + adType,
          creationParams: params,
          creationParamsCodec: StandardMessageCodec()
      );
    }
    return UiKitView(
        viewType: ADFURIKUN_VIEW_TYPE_BASE + adType,
        creationParams: params,
        creationParamsCodec: StandardMessageCodec()
    );
  }
}

==> adfurikun-1.5.0.tar.gz: lib/ad_base.dart <==
import 'dart:io';
import 'package:flutter/widgets.dart';
import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'adfurikun_plugin.dart';
import 'constants.dart';

abstract class AdfurikunAdBase {
  static int _nextNumber = 0;

  final String appId;
  final String adType;
  late final int number;

  AdfurikunAdBase(this.appId, this.adType) {
    number = _nextNumber++;
    AdfurikunPlugin.registerAd(this);
  }

  String method(String method) {
    return method + SEPARATOR_METHOD + adType;
  }

  Map<String, Object> args() {
    return {KEY_NUMBER: number, KEY_APP_ID: appId};
  }

  Map<String, Object> argsWithSize(double width, double height) {
    return {KEY_NUMBER: number, KEY_APP_ID: appId, KEY_WIDTH: width, KEY_HEIGHT: height, KEY_PLUGIN_VERSION: PLUGIN_VERSION};
  }

  Map<String, Object> argsWithPluginVersion() {
    return {KEY_NUMBER: number, KEY_APP_ID: appId, KEY_PLUGIN_VERSION: PLUGIN_VERSION};
  }

  void destroy() {
    AdfurikunPlugin.removeAd(this);
  }

  void notifyListener(MethodCall call) {
    print('override notifyListener method');
  }
}

class AdfurikunWidget extends StatefulWidget {
  final int number;
  final String appId;
  final String adType;
  final double width;
  final double height;

  AdfurikunWidget(this.number, this.appId, this.adType, this.width, this.height);

  @override
  AdfurikunWidgetState createState() => AdfurikunWidgetState(number, appId, adType, width, height);
}

class AdfurikunWidgetState extends State<AdfurikunWidget> {
  final int number;
  final String appId;
  final String adType;
  final double width;
  final double height;

  AdfurikunWidgetState(this.number, this.appId, this.adType, this.width, this.height);

  @override
  Widget build(BuildContext context) {
    Map<String, Object> params = {KEY_NUMBER: number, KEY_APP_ID: appId, KEY_WIDTH: width, KEY_HEIGHT: height, KEY_PLUGIN_VERSION: PLUGIN_VERSION};
    if (Platform.isAndroid) {
      return AndroidView(
          viewType: ADFURIKUN_VIEW_TYPE_BASE + adType,
          creationParams: params,
          creationParamsCodec: StandardMessageCodec()
      );
    }
    return UiKitView(
        viewType: ADFURIKUN_VIEW_TYPE_BASE + adType,
        creationParams: params,
        creationParamsCodec: StandardMessageCodec()
    );
  }
}
